@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: ip.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: ip.c 1172 2006-11-11 13:32:14Z d $ */
 
 /* Internet protocol version 4 */
 
@@ -160,6 +160,9 @@ ip_fragment(p, end, offset)
 	memcpy(&ipfkey.dst, &ip->ip_dst, sizeof ipfkey.dst);
 	memcpy(&ipfkey.id, &ip->ip_id, sizeof ipfkey.id);
 
+#if !defined(IP_OFFMASK)
+# define IP_OFFMASK 0x1fff
+#endif
 	if (offset & IP_MF) {
 		if (paylen & 7)
 			return "ip fragments";	/* bad length */
@@ -175,7 +178,7 @@ ip_fragment(p, end, offset)
 	if ((offset & IP_OFFMASK) == 0)
 		tag = ip_pkt_tag(p, end);
 	else {
-		int len;
+		size_t len;
 		char *dp;
 		dp = (char *)fragtab_get(ip_fragtab, &ipfkey, 0, &len);
 		if (dp)
@@ -218,6 +221,7 @@ ip_pkt_tag(p, end)
 		    tag_combine(ip_lookup(&ip->ip_src), ip_lookup(&ip->ip_dst))
 		);
 		return tag;
+#if HAVE_NETINET_IP6_H
 	case IPPROTO_IPV6:	/* RFC1933 4.1.5 */
 		snprintf(tag, sizeof tag, "ip %s", ip6_tag(p + hlen, end));
 		/*
@@ -227,6 +231,7 @@ ip_pkt_tag(p, end)
 		 * than how the data is encoded.
 		 */
 		return tag;
+#endif
 	default:
 		snprintf(tag, sizeof tag, "ip proto %u %s", ip->ip_p,
 		    tag_combine(ip_lookup(&ip->ip_src),
