@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: resize.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: resize.c 1172 2006-11-11 13:32:14Z d $ */
 
 /*
  * This compilation unit provides a callback mechanism for display.c
@@ -35,10 +35,13 @@
 
 #include "compat.h"
 
+#ifdef SIGWINCH
 static RETSIGTYPE sigwinch();
+#endif
 
 static volatile int *flagp = NULL;
 
+#ifdef SIGWINCH
 /* Set the flag when the window size changes */
 static RETSIGTYPE
 sigwinch(sig)
@@ -47,6 +50,7 @@ sigwinch(sig)
 	if (flagp)
 		*flagp = 1;
 }
+#endif
 
 /* Install a signal handler that sets a given flag when the window resizes */
 void
@@ -55,7 +59,7 @@ resize_init(fp)
 {
 	flagp = fp;
 	*flagp = 0;
-#ifndef SIGWINCH
+#ifdef SIGWINCH
 	if (signal(SIGWINCH, sigwinch) == SIG_ERR)
 		err(1, "signal");
 #endif
@@ -68,7 +72,9 @@ resize()
 	struct winsize ws;
 
 	*flagp = 0;
+#if HAVE_RESIZETERM
 	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws) == -1)
 		err(1, "TIOCGWINSZ");
 	resizeterm(ws.ws_row, ws.ws_col);
+#endif
 }
